@@ -6,7 +6,7 @@
 #    By: charles <charles.cabergs@gmail.com>        +#+  +:+       +#+         #
 #                                                 +#+#+#+#+#+   +#+            #
 #    Created: 2020/07/15 18:24:32 by charles           #+#    #+#              #
-#    Updated: 2021/02/05 20:12:53 by charles          ###   ########.fr        #
+#    Updated: 2021/02/24 08:03:17 by cacharle         ###   ########.fr        #
 #                                                                              #
 # ############################################################################ #
 
@@ -23,11 +23,17 @@ def parse_args():
         description="Test for the minishell project of school 42.",
         formatter_class=argparse.RawTextHelpFormatter,
         epilog=textwrap.dedent("""
-            Made by cacharle
-            https://github.com/cacharle
-            https://cacharle.xyz
+            Made by cacharle - https://cacharle.xyz
         """)
     )
+    parser.add_argument(
+        "-p", "--path", default=config.MINISHELL_DIR,
+        help="Path to minishell directory"
+    )
+    parser.add_argument(
+        "-l", "--list", action="store_true",
+        help="Print available test suites"
+    )
     parser.add_argument(
         "-k", "--check-leaks", action="store_true",
         help="Run valgrind on tests (disable usual comparison with bash)"
@@ -56,10 +62,6 @@ def parse_args():
         "-n", "--no-bonus", action="store_true",
         help="Disable bonus tests"
     )
-    parser.add_argument(
-        "-l", "--list", action="store_true",
-        help="Print available test suites"
-    )
     parser.add_argument(
         "-m", "--make", action="store_true",
         help="Make minishell and exit"
@@ -68,10 +70,6 @@ def parse_args():
         "-g", "--pager", action="store_true",
         help="After running the test, display the result in a pager of your choice"
     )
-    parser.add_argument(
-        "-p", "--path", default=config.MINISHELL_DIR,
-        help="Path to minishell directory"
-    )
     parser.add_argument(
         "suites", nargs='*', metavar="suite",
         help=textwrap.dedent("""\
